#include "ac_plugin.h"
#include "Undoable.h"
#include <stdio.h>
#include <string.h>

//---------------------------------------------------------------------------------------
// Perform the edge select
static void ddhseloutedge()
{
   // Ensure we're in Vertex mode
   if( ac_get_select_mode() != SELECT_VERTEX )
   {
      message_dialog( "seloutedge - ust be in Vertex mode" );
      return;
   }
   // Add undoable
   add_undoable_change_selection( "select outer edges" );
   // Gather the selected edges
   List *edges = ac_selection_get_edges( false );
   List *vertlist = NULL;
   for( List *l = edges; l != NULL; l = l->next )
   {
      ACEdge *e = ( ACEdge * )( l->data );
      if( e->connected == 1 )
      {
         list_add_item_unique( &vertlist, e->v1 );
         list_add_item_unique( &vertlist, e->v2 );
      }
   }
   ac_edgelist_free( &edges );
   clear_selection();
   ac_selection_select_vertexlist( vertlist );
   list_free( &vertlist );
   redraw_all();
}
//---------------------------------------------------------------------------------------
AC3D_PLUGIN_FUNC int AC3DPluginInit( AC3DPluginInitData *d )
{
   static bool firstTime = true;
   if( firstTime )
   {
      ac_add_command( "ddhseloutedge", ddhseloutedge );
      ac_add_tools_menu_item( "Select outer edges", "ac3d ddhseloutedge",
                              "Select only outer edges from the current selection" );
      firstTime = false;
   }
   return 0;
}
//---------------------------------------------------------------------------------------
AC3D_PLUGIN_FUNC int AC3DPluginExit()
{
   return 0;
}
//---------------------------------------------------------------------------------------
AC3D_PLUGIN_FUNC char *AC3DPluginAbout()
{
   return( "Select outer edges - version 1.0 - Dennis Hawthorne" );
}
//---------------------------------------------------------------------------------------
AC3D_PLUGIN_FUNC char *AC3DPluginInfo()
{
   return( "Select outer edges - Execute the \"select outer edges\" item under the \"Tools\" menu while in Vertex mode.  Any selected vertices that are part of an edge belonging to more than one surface will be deselected." );
}
//---------------------------------------------------------------------------------------

